==> mcp-server-http4s_3-0.2.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"mcp-server-http4s","t":"mcp-server-http4s","d":"","k":"static","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#","e":false,"i":"","n":"ch.linkyard.mcp.jsonrpc2.transport.http4s","t":"ch.linkyard.mcp.jsonrpc2.transport.http4s","d":"","k":"package","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#SessionId-0","e":false,"i":"","n":"SessionId","t":"SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"type","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#authentication-ffffff5a","e":false,"i":"extension (req: Request[IO])","n":"authentication","t":"authentication: Authentication","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#serverRoot-f01","e":false,"i":"extension (req: Request[IO])","n":"serverRoot","t":"serverRoot: Uri","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/McpServerRoute$.html#","e":false,"i":"","n":"McpServerRoute","t":"McpServerRoute","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/McpServerRoute$.html#route-fffffc2f","e":false,"i":"","n":"route","t":"route[Auth](handler: JsonRpcConnectionHandler[IO], root: Path)(using store: SessionStore[IO]): HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.McpServerRoute","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#","e":false,"i":"","n":"OAuthAuthorizationServer","t":"OAuthAuthorizationServer(authConfig: IO[Json])","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#rootUri-0","e":false,"i":"","n":"rootUri","t":"rootUri: Uri","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#route-0","e":false,"i":"","n":"route","t":"route: HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer$.html#","e":false,"i":"","n":"OAuthAuthorizationServer","t":"OAuthAuthorizationServer","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer$.html#fromOidcServer-fffff5d3","e":false,"i":"","n":"fromOidcServer","t":"fromOidcServer(root: Uri)(using client: Client[IO]): Resource[IO, OAuthAuthorizationServer]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#","e":false,"i":"","n":"OAuthMiddleware","t":"OAuthMiddleware(name: String, authorizationServers: List[Uri], scopes: List[String], validateToken: String => IO[Boolean], audienceOverride: Option[Uri])","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#protect-0","e":false,"i":"","n":"protect","t":"protect: HttpRoutes[IO] => HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#protectMcp-b00","e":false,"i":"","n":"protectMcp","t":"protectMcp(mcpRoute: HttpRoutes[IO]): HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#wellKnownRoutes-0","e":false,"i":"","n":"wellKnownRoutes","t":"wellKnownRoutes: HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#","e":false,"i":"","n":"SessionId","t":"SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#asString-fffff2ca","e":false,"i":"extension (id: SessionId)","n":"asString","t":"asString: String","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#generate-362","e":false,"i":"","n":"generate","t":"generate[F[_] : Sync]: F[SessionId]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#parse-fffffd22","e":false,"i":"","n":"parse","t":"parse(s: String): Option[SessionId]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#","e":false,"i":"","n":"SessionStore","t":"SessionStore[F[_]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"trait","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#close-fffff5f8","e":false,"i":"","n":"close","t":"close(id: SessionId): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#get-fffff5f8","e":false,"i":"","n":"get","t":"get(id: SessionId): F[Option[StatefulConnection[F]]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#open-47e","e":false,"i":"","n":"open","t":"open(session: StatefulConnection[F], cleanup: F[Unit]): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore$.html#","e":false,"i":"","n":"SessionStore","t":"SessionStore","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore$.html#inMemory-fffffdfd","e":false,"i":"","n":"inMemory","t":"inMemory[F[_] : Async](idleTimeout: FiniteDuration): Resource[F, SessionStore[F]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#","e":false,"i":"","n":"StatefulConnection","t":"StatefulConnection[F[_]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#connection-0","e":false,"i":"","n":"connection","t":"connection: JsonRpcConnection[F]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"val","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#receivedFromClient-fffff797","e":false,"i":"","n":"receivedFromClient","t":"receivedFromClient(message: MessageEnvelope): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#sessionId-0","e":false,"i":"","n":"sessionId","t":"sessionId: SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"val","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#streamNonRequestRelated-0","e":false,"i":"","n":"streamNonRequestRelated","t":"streamNonRequestRelated: Stream[F, Message]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#streamRequestReleated-617","e":false,"i":"","n":"streamRequestReleated","t":"streamRequestReleated(id: Id): Stream[F, Message]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection$.html#","e":false,"i":"","n":"StatefulConnection","t":"StatefulConnection","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection$.html#create-240","e":false,"i":"","n":"create","t":"create[F[_] : Async](capacity: Int): F[StatefulConnection[F]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""}];

==> mcp-server-http4s_3-0.3.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"mcp-server-http4s","t":"mcp-server-http4s","d":"","k":"static","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#","e":false,"i":"","n":"ch.linkyard.mcp.jsonrpc2.transport.http4s","t":"ch.linkyard.mcp.jsonrpc2.transport.http4s","d":"","k":"package","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#SessionId-0","e":false,"i":"","n":"SessionId","t":"SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"type","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#authentication-ffffff5a","e":false,"i":"extension (req: Request[IO])","n":"authentication","t":"authentication: Authentication","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#clientIp-4f","e":false,"i":"extension (req: Request[IO])","n":"clientIp","t":"clientIp: Option[IpAddress]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#defaultPort-d90","e":false,"i":"extension (scheme: Scheme)","n":"defaultPort","t":"defaultPort: Port","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#scheme-4d0","e":false,"i":"extension (req: Request[IO])","n":"scheme","t":"scheme: Scheme","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#serverAuthority-4f","e":false,"i":"extension (req: Request[IO])","n":"serverAuthority","t":"serverAuthority: Option[String]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#serverHost-4f","e":false,"i":"extension (req: Request[IO])","n":"serverHost","t":"serverHost: Option[Host]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s.html#serverRoot-f01","e":false,"i":"extension (req: Request[IO])","n":"serverRoot","t":"serverRoot: Uri","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/McpServerRoute$.html#","e":false,"i":"","n":"McpServerRoute","t":"McpServerRoute","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/McpServerRoute$.html#route-fffffc2f","e":false,"i":"","n":"route","t":"route[Auth](handler: JsonRpcConnectionHandler[IO], root: Path)(using store: SessionStore[IO]): HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.McpServerRoute","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#","e":false,"i":"","n":"OAuthAuthorizationServer","t":"OAuthAuthorizationServer(authConfig: IO[Json])","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#rootUri-0","e":false,"i":"","n":"rootUri","t":"rootUri: Uri","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer.html#route-0","e":false,"i":"","n":"route","t":"route: HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer$.html#","e":false,"i":"","n":"OAuthAuthorizationServer","t":"OAuthAuthorizationServer","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthAuthorizationServer$.html#fromOidcServer-fffff5d3","e":false,"i":"","n":"fromOidcServer","t":"fromOidcServer(root: Uri)(using client: Client[IO]): Resource[IO, OAuthAuthorizationServer]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthAuthorizationServer","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#","e":false,"i":"","n":"OAuthMiddleware","t":"OAuthMiddleware(name: String, authorizationServers: List[Uri], scopes: List[String], validateToken: String => IO[Boolean], audienceOverride: Option[Uri])","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#protect-0","e":false,"i":"","n":"protect","t":"protect: HttpRoutes[IO] => HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#protectMcp-b00","e":false,"i":"","n":"protectMcp","t":"protectMcp(mcpRoute: HttpRoutes[IO]): HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/OAuthMiddleware.html#wellKnownRoutes-0","e":false,"i":"","n":"wellKnownRoutes","t":"wellKnownRoutes: HttpRoutes[IO]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.OAuthMiddleware","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#","e":false,"i":"","n":"SessionId","t":"SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#asString-fffff2ca","e":false,"i":"extension (id: SessionId)","n":"asString","t":"asString: String","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#generate-362","e":false,"i":"","n":"generate","t":"generate[F[_] : Sync]: F[SessionId]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionId$.html#parse-fffffd22","e":false,"i":"","n":"parse","t":"parse(s: String): Option[SessionId]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionId","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#","e":false,"i":"","n":"SessionStore","t":"SessionStore[F[_]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"trait","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#close-fffff5f8","e":false,"i":"","n":"close","t":"close(id: SessionId): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#get-fffff5f8","e":false,"i":"","n":"get","t":"get(id: SessionId): F[Option[StatefulConnection[F]]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore.html#open-47e","e":false,"i":"","n":"open","t":"open(session: StatefulConnection[F], cleanup: F[Unit]): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore$.html#","e":false,"i":"","n":"SessionStore","t":"SessionStore","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/SessionStore$.html#inMemory-fffffdfd","e":false,"i":"","n":"inMemory","t":"inMemory[F[_] : Async](idleTimeout: FiniteDuration): Resource[F, SessionStore[F]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.SessionStore","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#","e":false,"i":"","n":"StatefulConnection","t":"StatefulConnection[F[_]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"class","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#connection-0","e":false,"i":"","n":"connection","t":"connection: JsonRpcConnection[F]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"val","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#receivedFromClient-fffff797","e":false,"i":"","n":"receivedFromClient","t":"receivedFromClient(message: MessageEnvelope): F[Unit]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#sessionId-0","e":false,"i":"","n":"sessionId","t":"sessionId: SessionId","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"val","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#streamNonRequestRelated-0","e":false,"i":"","n":"streamNonRequestRelated","t":"streamNonRequestRelated: Stream[F, Message]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection.html#streamRequestReleated-617","e":false,"i":"","n":"streamRequestReleated","t":"streamRequestReleated(id: Id): Stream[F, Message]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection$.html#","e":false,"i":"","n":"StatefulConnection","t":"StatefulConnection","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s","k":"object","x":""},
{"l":"ch/linkyard/mcp/jsonrpc2/transport/http4s/StatefulConnection$.html#create-fffff52f","e":false,"i":"","n":"create","t":"create[F[_] : Async](info: Http, capacity: Int): F[StatefulConnection[F]]","d":"ch.linkyard.mcp.jsonrpc2.transport.http4s.StatefulConnection","k":"def","x":""}];
